.. django-defender documentation master file, created by
   sphinx-quickstart on Fri Nov  8 18:52:29 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../README.rst
.. include:: ../CONTRIBUTING.rst
.. include:: ../CHANGES.rst
